@@ -84,6 +84,10 @@ This module probably should not be used for life support or military
 purposes, and it B<must> not be used for unsolicited commercial email
 or other bulk advertising.
 
+=head1 REPOSITORY
+
+L<https://github.com/brianary/Lingua-EN-MatchNames>
+
 =head1 AUTHOR
 
 Brian Lalonde, E<lt>brian@webcoder.infoE<gt>
@@ -120,7 +124,7 @@ use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use vars qw($debug);
 
-$VERSION=     '1.34';
+$VERSION=     '1.35';
 @ISA=         qw(Exporter);
 @EXPORT=      qw(name_eq);
 @EXPORT_OK=   qw(fname_eq lname_eq);
